#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-pieces
version:              0.2.1
visibility:           public
id:                   path-pieces-0.2.1-5gT7wFDsgDLEW6f8EG31Nu
key:                  path-pieces-0.2.1-5gT7wFDsgDLEW6f8EG31Nu
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            unstable
synopsis:             Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.

category:             Web, Yesod
abi:                  69ed2a5a622bb5af857954c527bf1b9a
exposed:              True
exposed-modules:      Web.PathPieces
import-dirs:          /usr/lib/ghc-8.10.5/site-local/path-pieces-0.2.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/path-pieces-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/path-pieces-0.2.1
hs-libraries:         HSpath-pieces-0.2.1-5gT7wFDsgDLEW6f8EG31Nu
depends:              base-4.14.2.0 text-1.2.4.1 time-1.9.3
haddock-interfaces:   /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html:         /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

